==> haskell-yesod-persistent-1.6.0.8-508-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-DKid0qUNvJ4HRqcvLpezmD
key:                  yesod-persistent-1.6.0.8-DKid0qUNvJ4HRqcvLpezmD
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  9537e613913508b8affc5a52ea541551
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-DKid0qUNvJ4HRqcvLpezmD
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    persistent-2.14.5.2-GJyCnJ8J8PvBVRSOBxUsv4
    resource-pool-0.2.3.2-3uIbkUYrHNdAfRBpvdjlDL
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx transformers-0.6.1.0
    yesod-core-1.6.27.1-9M5c258biFQ3gXF13H4oaO

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-510-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-1PT3vTEjdj623nY4CmQUQK
key:                  yesod-persistent-1.6.0.8-1PT3vTEjdj623nY4CmQUQK
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  675025042d09b72bf48eb89ace8f6b78
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-1PT3vTEjdj623nY4CmQUQK
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    resource-pool-0.2.3.2-73AdA0RAXUL5Z2VU9q4gfk
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs transformers-0.6.1.0
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
